{% extends "richie/fullwidth.html" %}
{% load cms_tags i18n %}

{% block subheader_content %}
<div class="subheader__container">
    <h1 class="subheader__title">{{ current_page.get_title }}</h1>
</div>
{% endblock subheader_content %}


{% block content %}
<div class="organization-list">
    <div class="organization-list__content">
    {% for page in current_page.get_child_pages %}
        {% if page.organization %}
            {% include "courses/cms/fragment_organization_glimpse.html" with organization=page.organization organization_variant="card" %}
        {% endif %}
    {% empty %}
        <p class="organization-list__empty">{% trans "No organization yet" %}</p>
    {% endfor %}
    </div>
</div>
{% endblock content %}
